==> error-overlay-webpack-plugin-0.1.7.tgz: package/lib/index.js <==
"use strict";

var _errorOverlayMiddleware = _interopRequireDefault(require("react-dev-utils/errorOverlayMiddleware"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var ErrorOverlayPlugin =
/*#__PURE__*/
function () {
  function ErrorOverlayPlugin() {
    _classCallCheck(this, ErrorOverlayPlugin);
  }

  _createClass(ErrorOverlayPlugin, [{
    key: "apply",
    value: function apply(compiler) {
      var className = this.constructor.name;
      if (compiler.options.mode !== 'development') return;
      compiler.hooks.entryOption.tap(className, function (context, entry) {
        var chunkPath = require.resolve('./entry');

        adjustEntry(entry, chunkPath);
      });
      compiler.hooks.afterResolvers.tap(className, function (_ref) {
        var options = _ref.options;

        if (options.devServer) {
          var originalBefore = options.devServer.before;

          options.devServer.before = function (app, server) {
            if (originalBefore) {
              originalBefore(app, server);
            }

            app.use((0, _errorOverlayMiddleware.default)());
          };
        }
      });
    }
  }]);

  return ErrorOverlayPlugin;
}();

function adjustEntry(entry, chunkPath) {
  if (typeof entry === 'string') {
    throw new Error("We currently do not inject our entry code into single-file anonymous entries.\nPlease use a multi-main (array) or object-form `entry` setting for now.");
  }

  if (Array.isArray(entry)) {
    if (!entry.includes(chunkPath)) {
      entry.unshift(chunkPath);
    }
  } else {
    Object.keys(entry).forEach(function (entryName) {
      entry[entryName] = adjustEntry(entry[entryName], chunkPath);
    });
  }

  return entry;
}

module.exports = ErrorOverlayPlugin;

==> error-overlay-webpack-plugin-0.2.0.tgz: package/lib/index.js <==
"use strict";

var _errorOverlayMiddleware = _interopRequireDefault(require("react-dev-utils/errorOverlayMiddleware"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var chunkPathBasic = require.resolve('./entry-basic');

var chunkPathDevServer = require.resolve('./entry-devserver');

var ErrorOverlayPlugin =
/*#__PURE__*/
function () {
  function ErrorOverlayPlugin() {
    _classCallCheck(this, ErrorOverlayPlugin);
  }

  _createClass(ErrorOverlayPlugin, [{
    key: "apply",
    value: function apply(compiler) {
      var className = this.constructor.name;
      if (compiler.options.mode !== 'development') return;
      var devServerEnabled = !!compiler.options.devServer;
      compiler.hooks.entryOption.tap(className, function (context, entry) {
        adjustEntry(entry, devServerEnabled);
      });
      compiler.hooks.afterResolvers.tap(className, function (_ref) {
        var options = _ref.options;

        if (devServerEnabled) {
          var originalBefore = options.devServer.before;

          options.devServer.before = function (app, server) {
            if (originalBefore) {
              originalBefore(app, server);
            }

            app.use((0, _errorOverlayMiddleware.default)());
          };
        }
      });
    }
  }]);

  return ErrorOverlayPlugin;
}();

function adjustEntry(entry, enableDevServer) {
  if (typeof entry === 'string') {
    throw new Error("We currently do not inject our entry code into single-file anonymous entries.\nPlease use a multi-main (array) or object-form `entry` setting for now.");
  }

  if (Array.isArray(entry)) {
    if (enableDevServer) {
      if (!entry.includes(chunkPathDevServer)) {
        entry.unshift(chunkPathDevServer);
      }
    }

    if (!entry.includes(chunkPathBasic)) {
      entry.unshift(chunkPathBasic);
    }
  } else {
    Object.keys(entry).forEach(function (entryName) {
      entry[entryName] = adjustEntry(entry[entryName], enableDevServer);
    });
  }

  return entry;
}

module.exports = ErrorOverlayPlugin;
